import opics as op


def test_c() -> None:
    assert op.globals.C == 299792458
